@@ -3,6 +3,10 @@
 // license version 2.0 or 2.1.  You should have received a copy of the
 // LGPL license along with this library if you did not you can find it
 // at http://www.gnu.org/.
+#ifdef WIN32PORT
+#include "minwin.h" //minimum windows declarations.
+#endif
+
 #include "settings.h"
 
 #ifdef USE_POSIX_REGEX
@@ -11,7 +15,7 @@
 #endif
 
 #include "stack_ptr.hpp"
-#include "cache-t.hpp"
+#include "cache.hpp"
 #include "string.hpp"
 #include "vector.hpp"
 #include "config.hpp"
@@ -27,7 +31,9 @@
 #include "asc_ctype.hpp"
 #include "iostream.hpp"
 
-namespace acommon {
+#include "gettext.h"
+
+namespace aspell {
 
   class FilterMode {
   public:
@@ -66,7 +72,7 @@ namespace acommon {
     const String & getDescription() const {return desc_;}
     PosibErr<void> expand(Config * config);
     PosibErr<void> build(FStream &, int line = 1, 
-                         const char * name = "mode file");
+                         const char * fname = "mode file");
 
     ~FilterMode();
   private:
@@ -117,7 +123,7 @@ namespace acommon {
       c->filter_mode_notifier = this;
     }
     
-    ModeNotifierImpl * clone(Config * c) const {return new ModeNotifierImpl(*this, c);}
+    Notifier * clone(Config * c) const {return new ModeNotifierImpl(*this, c);}
 
     PosibErr<void> item_updated(const KeyInfo * ki, ParmStr);
     PosibErr<void> list_updated(const KeyInfo * ki);
@@ -133,6 +139,7 @@ namespace acommon {
     bool extOnly = false;
     
     if (    ( toMagic == "" )
+         || ( toMagic == "<noregex>" )
          || ( toMagic == "<nomagic>" )
          || ( toMagic == "<empty>" ) ) {
       extOnly = true;
@@ -236,7 +243,7 @@ namespace acommon {
       for ( Vector<MagicString>::iterator it = magicKeys.begin() ;
             it != magicKeys.end() ; it++ ) {
         PosibErr<bool> magicMatch = it->matchFile(in,ext);
-        if (    magicMatch 
+        if (    magicMatch.data 
              || magicMatch.has_err() ) {
           if ( closeFile ) {
             fclose ( in );
@@ -325,9 +332,9 @@ namespace acommon {
 
     number.erase(magicFilePosition,magic.size() - magicFilePosition);
 
-    char * num = (char *)number.str();
-    char * numEnd = num + number.size();
-    char * endHere = numEnd;
+    const char * num = number.str();
+    const char * numEnd = num + number.size();
+    const char * endHere = numEnd;
     long position = 0;
 
     if (    ( number.size() == 0 ) 
@@ -440,10 +447,13 @@ namespace acommon {
     return no_err;  
   }
 
-  PosibErr<void> FilterMode::build(FStream & toParse, int line0, const char * name) {
+  PosibErr<void> FilterMode::build(FStream & toParse, int line0, const char * fname) {
 
     String buf;
     DataPair dp;
+
+    file_ = fname;
+
     dp.line_num = line0;
 
     while ( getdata_pair(toParse, dp, buf) ) {
@@ -464,7 +474,7 @@ namespace acommon {
 
       } else {
         
-        return make_err(bad_mode_key,dp.key).with_file(name,dp.line_num);
+        return make_err(bad_mode_key,dp.key).with_file(fname,dp.line_num);
       }
     }
 
@@ -481,7 +491,7 @@ namespace acommon {
     for ( FilterModeList::iterator it = fm->begin(); it != fm->end(); it++ ) 
     {
       if ( it->lockFileToMode(filename,in) ) {
-        config->replace("mode", it->modeName().str());
+        RET_ON_ERR(config->replace("mode", it->modeName().str()));
         break;
       }
     }
@@ -558,8 +568,7 @@ namespace acommon {
         pathPos = pathPosEnd + 1;
       }
       possMode.erase(0,pathPos);
-      possMode.ensure_null_end();
-      to_lower(possMode.data());
+      to_lower(possMode.mstr());
 
       Vector<FilterMode>::iterator fmIt = filter_modes->begin();
 
@@ -575,7 +584,7 @@ namespace acommon {
 
       FStream toParse;
 
-      RET_ON_ERR(toParse.open(possModeFile.str(),"rb"));
+      RET_ON_ERR(toParse.open(possModeFile.str(),"r"));
 
       String buf;
       DataPair dp;
@@ -597,8 +606,10 @@ namespace acommon {
            || ( *(dp.value) == '\0' ) )
         return make_err(mode_version_requirement).with_file(possModeFile, dp.line_num);
 
+#ifdef FILTER_VERSION_CONTROL
       PosibErr<void> peb = check_version(dp.value.str);
       if (peb.has_err()) return peb.with_file(possModeFile, dp.line_num);
+#endif
       
       FilterMode collect(possMode);
       
@@ -693,15 +704,14 @@ namespace acommon {
 
             // partially unescape magic
             
-            magic.ensure_null_end();
-            char * dest = magic.data();
-            const char * src  = magic.data();
+            char * dest = magic.mstr();
+            const char * src  = magic.mstr();
             while (*src) {
               if (*src == '\\' && src[1] == '/' || src[1] == '#')
                 ++src;
               *dest++ = *src++;
             }
-            magic.resize(dest - magic.data());
+            magic.resize(dest - magic.mstr());
 
             PosibErr<bool> pe;
 
@@ -726,7 +736,7 @@ namespace acommon {
       
       }//while getdata_pair
       
-      RET_ON_ERR(collect.build(toParse,dp.line_num,possMode.str()));
+      RET_ON_ERR(collect.build(toParse,dp.line_num,possModeFile.str()));
 
       filter_modes->push_back(collect);
     }
